@@ -594,6 +594,8 @@ class DistributeEventConst(object):
 
     # 2022.08 虚拟商品确收
     CUS_CONFIRM_AT_VIRTUAL = "cus_confirm_at_virtual"
+    
+    CLOUDPRINT_SHIPPING_NUMBER = "cloudprint_shipping_number"
 
     FROM_TO_MAP = {
         PRINT: {
@@ -1042,6 +1044,13 @@ class DistributeEventConst(object):
                 DistributeStatus.VIRTUAL_INIT],
             DistributeEventConstKey.TO_STATUS_KEY: DistributeStatus.CUS_CONFIRM_AT_VIRTUAL,
         },
+        # 2022.12.16 云打印面单
+        CLOUDPRINT_SHIPPING_NUMBER:{
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.PACKAGED,
+            ],
+            DistributeEventConstKey.TO_STATUS_KEY: None
+        }
 
     }
 
@@ -1128,7 +1137,8 @@ class DistributeEventConst(object):
         AFSPLUS_TO_SELF_SERVICE: "转自提",
 
         # 虚拟商品
-        CUS_CONFIRM_AT_VIRTUAL: "虚拟商品确收"
+        CUS_CONFIRM_AT_VIRTUAL: "虚拟商品确收",
+        CLOUDPRINT_SHIPPING_NUMBER: "打印面单"
     }
 
 
@@ -1157,7 +1167,8 @@ def get_available_event_list(distribute_status):
         DistributeEventConst.RETURN_DEPOSIT,
         DistributeEventConst.OVERTIME_TAILPAY,
         DistributeEventConst.HAITAO_PACKAGE,
-        DistributeEventConst.UPDATE_DELIVER_TIME
+        DistributeEventConst.UPDATE_DELIVER_TIME,
+        DistributeEventConst.CLOUDPRINT_SHIPPING_NUMBER
     ]
     from_to_map = DistributeEventConst.FROM_TO_MAP
     for event_name, event_dict in from_to_map.items():
